register abstract method

Creates a new passkey on the device for the given request and returns the credential that must be sent to the relying party server.

Implementation

Future<RegisterResponseType> register(RegisterRequestType request);