types/types library

Classes

AuthenticateRequestType
The AuthenticateRequestType is used to create an authentication request and send it to the platform.
AuthenticateResponseType
The response returned by the platform after an authentication flow.
AuthenticatorSelectionType
Describes the relying party's requirements for the authenticator that should be used during a credential operation.
AvailabilityType
The base class for platform-specific availability information.
AvailabilityTypeAndroid
Represents the availability information specific to Android platforms.
AvailabilityTypeIOS
Represents the availability information specific to iOS platforms.
AvailabilityTypeWeb
Represents the availability information specific to web platforms.
AvailabilityTypeWindows
Represents the availability information specific to Windows platforms.
RegisterRequestType
The RegisterRequestType is used to create a registration request and send it to the platform.
RegisterResponseType
The response returned by the platform after a registration flow.
RelyingPartyType
The RelyingPartyType class wraps the data of a relying party. It is used to identify the party that is requesting authentication.
SignalAllAcceptedCredentialsRequestType
The SignalAllAcceptedCredentialsRequestType is used to tell the platform the complete set of credential IDs that the relying party still accepts for a given user, so that any others can be pruned from the credential picker.
SignalUnknownCredentialRequestType
The SignalUnknownCredentialRequestType is used to tell the platform that a credential is no longer recognized by the relying party, so that it can be removed from the credential picker and autofill suggestions.
UserType
The UserType class wraps the data of a user..

Enums

MediationType
Defines how user mediation (interaction) should be handled during credential operations.