PasskeyAuthenticatorInterface class abstract interface

Interface for authenticators that perform the platform WebAuthn ceremonies.

The passkeys package's PasskeyAuthenticator implements this interface. Depending on this interface (instead of the passkeys package directly) lets a package accept an authenticator without taking on the full plugin and its platform requirements.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate(AuthenticateRequestType request) Future<AuthenticateResponseType>
Authenticates the user with a passkey for the given request and returns the assertion that must be sent to the relying party server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(RegisterRequestType request) Future<RegisterResponseType>
Creates a new passkey on the device for the given request and returns the credential that must be sent to the relying party server.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited