authenticate abstract method
Authenticates the user with a passkey for the given request and returns
the assertion that must be sent to the relying party server.
Implementation
Future<AuthenticateResponseType> authenticate(
AuthenticateRequestType request,
);