signalAllAcceptedCredentials abstract method
Signals to the platform the complete set of credentials that the relying party still accepts for a user, so any others can be pruned from the credential picker.
Implementation
Future<void> signalAllAcceptedCredentials(
SignalAllAcceptedCredentialsRequestType request,
);