signalUnknownCredential abstract method
Signals to the platform that the credential in request is no longer
recognized by the relying party, so it can be removed from the credential
picker and autofill suggestions.
Implementation
Future<void> signalUnknownCredential(
SignalUnknownCredentialRequestType request,
);