PasskeysPlatform class abstract
The interface that implementations of passkeys must implement.
Platform implementations should extend this class
rather than implement it as Passkeys.
Extending this class (using extends) ensures that the subclass will get
the default implementation, while platform implementations that implements
this interface will be broken by newly added PasskeysPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- PasskeysPlatform
- Implementers
Constructors
- PasskeysPlatform()
- Constructs a PasskeysPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
AuthenticateRequestType request) → Future< AuthenticateResponseType> - Handles the platform-specific steps for the authentication flow (see https://webauthn.guide/#authentication) Namely it creates a signature for the challenge issued by the relying party
-
canAuthenticate(
) → Future< bool> - Returns true if passkeys are supported by the device We have deprecated this function (it will now always return true).
-
cancelCurrentAuthenticatorOperation(
) → Future< void> - Cancels the ongoing authenticator operation (if there is one). This is important for the case when conditional UI has been started but the user decides ignore that and login by typing his username instead.
-
getAvailability(
) → Future< AvailabilityType> - Retrieves the availability information for passkeys, user-verifying platform authenticators, and conditional mediation whenever possible
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
RegisterRequestType request) → Future< RegisterResponseType> - Handles the platform-specific steps for the registration flow (see https://webauthn.guide/#registration) Namely it creates a public/private key pair (only the public key will be returned)
-
signalAllAcceptedCredentials(
SignalAllAcceptedCredentialsRequestType request) → Future< void> - Signals to the platform the complete set of credentials that the relying party still accepts for a user. Platforms that support the WebAuthn Signal API can use this to prune any other credentials from the credential picker.
-
signalUnknownCredential(
SignalUnknownCredentialRequestType request) → Future< void> -
Signals to the platform that the credential in
requestis no longer recognized by the relying party. Platforms that support the WebAuthn Signal API can use this hint to remove the credential from the credential picker and autofill suggestions. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ PasskeysPlatform
-
The default instance of PasskeysPlatform to use.
getter/setter pair